# Calibration of Material

The calibration commands are used for material calibration.

## Create material calibrations

```{eval-rst}
.. autoclass:: abaqus.Calibration.CalibrationModel.CalibrationModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Calibration
        :recursive:
        :exclude: CalibrationModel
```
